@@ -61,8 +61,8 @@ class AzureImage(object):
 
     def __init__(
         self,
-        container: str,
-        storage_account: str,
+        container: str = None,
+        storage_account: str = None,
         credentials: dict = None,
         credentials_file: str = None,
         resource_group: str = None,
@@ -214,11 +214,21 @@ class AzureImage(object):
         If image exists and force replace is True delete
         the existing image before creation.
         """
+        if not self.container:
+            raise AzureImgUtilsException(
+                'Container is required to create a compute image'
+            )
+
         if not self.resource_group:
             raise AzureImgUtilsException(
                 'Resource group is required to create a compute image'
             )
 
+        if not self.storage_account:
+            raise AzureImgUtilsException(
+                'Storage account is required to create a compute image'
+            )
+
         exists = image_exists(self.compute_client, image_name)
 
         if exists and force_replace_image:
@@ -299,6 +309,11 @@ class AzureImage(object):
 
         A blob_url is generated for the container if one is not provided.
         """
+        if not self.container:
+            raise AzureImgUtilsException(
+                'Container is required to add an image to an offer'
+            )
+
         if not blob_url:
             blob_url = get_blob_url(
                 self.blob_service_client,
@@ -336,11 +351,7 @@ class AzureImage(object):
 
     def remove_image_from_offer(
         self,
-        image_version: str,
-        offer_id: str,
-        publisher_id: str,
-        sku: str,
-        generation_id: str = None,
+        image_urn: str,
         vm_images_key: str = None
     ):
         """
@@ -350,19 +361,17 @@ class AzureImage(object):
         is deleted and re-uploaded. To make the new image available
         the offer must be published and set to go-live.
         """
+        publisher_id, offer_id, plan_id, image_version = image_urn.split(':')
         offer_doc = self.get_offer_doc(offer_id, publisher_id)
 
-        kwargs = {
-            'generation_id': generation_id
-        }
-
+        kwargs = {}
         if vm_images_key:
             kwargs['vm_images_key'] = vm_images_key
 
         offer_doc = remove_image_version_from_offer(
             offer_doc,
             image_version,
-            sku,
+            plan_id,
             **kwargs
         )
         self.upload_offer_doc(
@@ -437,6 +446,12 @@ class AzureImage(object):
 
         Lazy blob service client initialization.
         """
+        if not self.storage_account:
+            raise AzureImgUtilsException(
+                'Storage account is required to authenticate storage '
+                'blob operations.'
+            )
+
         if not self._blob_service_client:
             if self.sas_token:
                 args = (
